<template>
    <el-dialog
        width="680px"
        :title="type"
        :visible="dislogVisible"
        :before-close="handleClose"
        :close-on-click-modal="false"
        :destroy-on-close="true"
        :class="[reqLoading ? 'dialog-box' : '']"
    >
        <div
            v-loading="reqLoading"
            element-loading-text="加载中..."
            element-loading-spinner="el-icon-loading"
        >
            <el-form
                ref="form"
                :rules="rules"
                :model="form"
                label-width="100px"
            >
                <el-row>
                    <el-col :span="23">
                        <el-form-item label="指标名称" prop="name">
                            <el-input v-model.trim="form.name"></el-input>
                        </el-form-item>
                    </el-col>
                    <el-col :span="23">
                        <el-form-item label="指标值" prop="key">
                            <el-input v-model.trim="form.key"></el-input>
                        </el-form-item>
                    </el-col>
                    <el-col :span="14">
                        <el-form-item label="指标单位" prop="unit">
                            <el-select
                                v-model.trim="form.unit"
                                placeholder="请选择"
                            >
                                <el-option
                                    v-for="item in unitOptions"
                                    :key="item.value"
                                    :label="item.label"
                                    :value="item.value"
                                >
                                </el-option>
                            </el-select>
                        </el-form-item>
                    </el-col>
                    <el-col :span="14">
                        <el-form-item label="所属时间" prop="fillDate">
                            <el-cascader
                                :props="{
                                    multiple: true,
                                    expandTrigger: 'hover',
                                }"
                                :options="options"
                                v-model="form.fillDate"
                                collapse-tags
                            ></el-cascader>
                        </el-form-item>
                    </el-col>
                    <el-col :span="23" prop="remarks">
                        <el-form-item label="备注">
                            <el-input
                                :rows="2"
                                type="textarea"
                                v-model="form.remarks"
                                :disabled="type == '详情' ? true : false"
                            ></el-input>
                        </el-form-item>
                    </el-col>
                </el-row>
            </el-form>
        </div>
        <div slot="footer" class="dialog-footer">
            <el-button
                type="primary"
                @click="handleSubmit"
                v-if="type !== '详情'"
                >提 交</el-button
            >
            <el-button @click="handleClose">取 消</el-button>
        </div>
    </el-dialog>
</template>

<script>
import utils from '@/utils.js'
import req from '@/request.js'
const portal = window.context.portal
export default {
    name: 'indexManageDialog',
    data() {
        return {
            reqLoading: false,
            dislogVisible: false,
            type: '新增',
            reportData: null,
            form: {
                name: '',
                key: '',
                unit: '分',
                fillDate: [],
                remarks: '',
            },
            rules: {
                name: [
                    {
                        required: true,
                        message: '请输入指标名称',
                        trigger: 'change',
                    },
                ],
                key: [
                    {
                        required: true,
                        message: '请输入指标值',
                        trigger: 'change',
                    },
                ],
                unit: [
                    {
                        required: true,
                        message: '请选择指标单位',
                        trigger: 'change',
                    },
                ],
                fillDate: [
                    {
                        required: true,
                        message: '请选择指标所属时间',
                        trigger: 'change',
                    },
                ],
            },
            options: [],
            unitOptions: [
                {
                    value: '分',
                    label: '分',
                },
                {
                    value: '%',
                    label: '%',
                },
            ],
        }
    },
    created() {},
    methods: {
        init() {
            let children = []
            for (let i = 1; i <= 12; i++) {
                children.push({
                    label: i + '月',
                    value: i,
                })
            }
            this.options = []
            for (let year = 2024; year < 2034; year++) {
                this.options.push({
                    label: year + '年',
                    value: year,
                    children,
                })
            }
        },
        async open(type, data) {
            this.dislogVisible = true
            this.reqLoading = true
            this.type = type
            if (data && data.id) {
                this.reportData = data
                await this.getDataById()
            }
            this.init()
            this.formarDataShow()
            this.reqLoading = false
        },
        getDataById() {
            return new Promise((resolve) => {
                req.get(
                    `${portal}/majorProjects/bizSpecialGroupWork/v1/${this.reportData.id}`
                ).then((res) => {
                    console.log(res.data)
                    if (res && res.data) {
                        this.form = res.data
                        resolve()
                    }
                })
            })
        },
        formarDataShow() {
            if (this.form.details && this.form.details.length) {
                this.row.forEach((item) => {
                    this.form.details.forEach((indexField) => {
                        if (indexField.groupCode == item.value) {
                            item[`${item.keyMap[indexField.indexCode]}_score`] =
                                indexField.indexScore
                            item[`${item.keyMap[indexField.indexCode]}_star`] =
                                indexField.indexStar
                        }
                    })
                })
            }
        },
        handleClose() {
            this.dislogVisible = false
            this.form = {
                name: '',
                key: '',
                unit: '分',
                fillDate: [],
                remarks: '',
            }
        },
        handleSubmit() {
            this.$refs.form.validate((valid) => {
                if (valid) {
                    this.reqLoading = true
                    this.formatDataSubmit()
                    console.log(this.form, 'submitData')
                    return
                    req.post(
                        `${portal}/majorProjects/bizSpecialGroupWork/v1/`,
                        this.form
                    ).then((res) => {
                        console.log(res)
                        this.reqLoading = false
                        if (res.data && res.data.state) {
                            this.$message.success('提交成功！')
                            this.$emit('refreshData')
                            this.handleClose()
                        }
                    })
                }
            })
        },
        formatDataSubmit() {
            this.form.dataTime = this.form.fillDate.map((item) => {
                return {
                    year: item[0],
                    month: item[1],
                }
            })
            this.form.unit == '分' ? (this.form.unit = '') : null
        },
    },
}
</script>

<style lang='scss' scoped>
/deep/ .el-dialog__body{
    max-height: calc(100% - 180px)!important;
}
/deep/ .el-dialog__footer{
    width: 100%;
    text-align: center!important;
}
.input-text{
    min-height: 20px;
    font-size: 14px;
}
/deep/.el-rate__icon{
    font-size: 18px !important;
    margin-right: 3px;
}
/deep/.el-rate__icon::before{
    font-size: 18px !important;
}
/deep/.el-rate__decimal{
    font-size: 18px !important;
}
/deep/ .el-table td.el-table__cell div{
    position: relative;
    overflow: inherit;
    .reset-star{
        position: absolute;
        right: 6px;
        top: -10px;
        font-size: 16px;
        color: #bdc2c7;
        display: none;
        cursor: pointer;
    }
}
/deep/ .el-table td.el-table__cell div:hover{
    .reset-star.show{
        display: block;
    }
}
</style>